diff --git a/mesh/gatt/src/mesh_gatt.c b/mesh/gatt/src/mesh_gatt.c
index d6b67a961..b2b9e2916 100644
--- a/mesh/gatt/src/mesh_gatt.c
+++ b/mesh/gatt/src/mesh_gatt.c
@@ -238,6 +238,7 @@ static void rx_state_clear(mesh_gatt_connection_t * p_conn)
 
 static uint16_t conn_index_alloc(uint16_t conn_handle)
 {
+    __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "conn_index_alloc: %d\n", conn_handle);
     for (uint32_t i = 0; i < MESH_GATT_CONNECTION_COUNT_MAX; ++i)
     {
         if (m_gatt.connections[i].conn_handle == BLE_CONN_HANDLE_INVALID)
@@ -252,6 +253,7 @@ static uint16_t conn_index_alloc(uint16_t conn_handle)
 
 static void conn_index_free(uint16_t conn_index)
 {
+    __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "conn_index_free: %d\n", conn_index);
     NRF_MESH_ASSERT(conn_index < MESH_GATT_CONNECTION_COUNT_MAX);
     rx_state_clear(&m_gatt.connections[conn_index]);
     tx_state_clear(&m_gatt.connections[conn_index]);
@@ -398,6 +400,10 @@ static void pdu_send_if_available(mesh_gatt_connection_t * p_conn)
 
         mesh_gatt_pdu_send(p_conn);
     }
+    else
+    {
+        __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "Couldn't pop packet from buffer\n");
+    }
 }
 
 static void tx_complete_send_and_enqueue(mesh_gatt_connection_t * p_conn)
diff --git a/mesh/gatt/src/proxy.c b/mesh/gatt/src/proxy.c
index 9928a0d81..5b5c52195 100644
--- a/mesh/gatt/src/proxy.c
+++ b/mesh/gatt/src/proxy.c
@@ -270,6 +270,7 @@ static void packet_send(proxy_connection_t * p_connection)
 
     if(mesh_gatt_packet_send(connection_index(p_connection), p_connection->p_alloc_packet) != NRF_SUCCESS)
     {
+        __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "mesh_gatt_packet_send failed\n");
         mesh_gatt_packet_discard(connection_index(p_connection), p_connection->p_alloc_packet);
     }
     p_connection->p_alloc_packet = NULL;
@@ -856,12 +857,15 @@ void core_tx_packet_send_cb(core_tx_bearer_t * p_bearer, const uint8_t * p_packe
     proxy_connection_t * p_connection = PARENT_BY_FIELD_GET(proxy_connection_t, bearer, p_bearer);
     NRF_MESH_ASSERT(p_connection->p_alloc_packet);
 
+    __LOG_XB(LOG_SRC_APP, LOG_LEVEL_INFO, "core_tx_packet_send_cb", p_packet, packet_length);
+
     memcpy(p_connection->p_alloc_packet, p_packet, packet_length);
     packet_send(p_connection);
 }
 
 void core_tx_packet_discard_cb(core_tx_bearer_t * p_bearer)
 {
+    __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "core_tx_packet_discard_cb\n");
     NRF_MESH_ASSERT(p_bearer);
     proxy_connection_t * p_connection = PARENT_BY_FIELD_GET(proxy_connection_t, bearer, p_bearer);
     packet_discard(p_connection);
diff --git a/models/foundation/config/src/config_server.c b/models/foundation/config/src/config_server.c
index fdcbf2d43..a1613113f 100644
--- a/models/foundation/config/src/config_server.c
+++ b/models/foundation/config/src/config_server.c
@@ -877,6 +877,7 @@ static void handle_composition_data_get(access_model_handle_t handle, const acce
 {
     if (p_message->length != sizeof(config_msg_composition_data_get_t))
     {
+        __LOG(LOG_SRC_APP, LOG_LEVEL_INFO, "composition_data_get: Incorrect length: %d", p_message->length);
         return;
     }
 
@@ -892,6 +893,8 @@ static void handle_composition_data_get(access_model_handle_t handle, const acce
     uint16_t size = CONFIG_COMPOSITION_DATA_SIZE;
     config_composition_data_get(p_response->data, &size);
 
+    __LOG_XB(LOG_SRC_APP, LOG_LEVEL_INFO, "composition_data_get:", p_response->data, size);
+
     send_reply(handle, p_message, CONFIG_OPCODE_COMPOSITION_DATA_STATUS, buffer,
                sizeof(config_msg_composition_data_status_t) + size, nrf_mesh_unique_token_get());
